@@ -1,6 +1,6 @@
 ;;; once.el --- Add-hook and eval-after-load, but only once  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2025 Martin Edström
+;; Copyright (C) 2025-2026 Martin Edström
 
 ;; This program is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 ;; URL:      https://github.com/meedstrom/once
 ;; Created:  2025-12-12
 ;; Keywords: lisp
-;; Package-Version: 20260202.2255
-;; Package-Revision: 3c3b778d557f
-;; Package-Requires: ((emacs "29.1"))
+;; Package-Version: 20260218.751
+;; Package-Revision: 8bb03796ca78
+;; Package-Requires: ((emacs "26.1") (compat "30.1"))
 
 
 ;;; Commentary:
@@ -93,6 +93,7 @@
 ;;; Code:
 
 (require 'cl-lib)
+(require 'compat)
 
 (defvar once--counter 0)
 (defvar once-functions nil
